@@ -48,9 +48,6 @@ class TestVideo(BaseTest):
         assert response.status_code == 200
         assert "Successfully deleted 1 videos" in response.json()['message']
 
-    def test_delete(self):
-        videos_to_test = self.vdocipher.Video(id='cfc80862639d45ba8ade5b0b90332f44').delete()
-
     def test_video_get(self, video):
         video_obj = video.get()
 
